require "warning_filter/filter"
require "tempfile"

RSpec.describe WarningFilter::Filter do
  it "filters warnings that include a gem path" do
    example = "ruby_progressbar@db2de68"
    original = original_for_example(example)
    expected = expected_for_example(example)
    output = Tempfile.new(example)
    allow(Gem).to receive(:path).and_return(
      [
        "/Users/grayson/.gem/ruby/2.1.2",
        "/Users/grayson/.rbenv/versions/2.1.2/lib/ruby/gems/2.1.0",
      ]
    )
    filter = WarningFilter::Filter.new(output)

    original.lines.each do |line|
      filter.write(line)
    end

    output.rewind
    expect(output.read).to eq expected
  end

  it "does not interfere with backtraces" do
    example = "ruby_progressbar_error@db2de68"
    original = File.read("#{fixture_path}/#{example}.stderr")
    expected = File.read("#{fixture_path}/#{example}.filtered.stderr")
    output = Tempfile.new(example)
    allow(Gem).to receive(:path).and_return(
      [
        "/Users/grayson/.gem/ruby/2.1.2",
        "/Users/grayson/.rbenv/versions/2.1.2/lib/ruby/gems/2.1.0",
      ]
    )
    filter = WarningFilter::Filter.new(output)

    original.lines.each do |line|
      filter.write(line)
    end

    output.rewind
    expect(output.read).to eq expected
  end

  def original_for_example(example)
    File.read("#{fixture_path}/#{example}.stderr")
  end

  def expected_for_example(example)
    File.read("#{fixture_path}/#{example}.filtered.stderr")
  end

  def fixture_path
    "spec/fixtures"
  end
end
